@@ -1,18 +1,18 @@
-quadFuncCalc <- function( xNames, data, allCoef, quadHalf = TRUE ) {
+quadFuncCalc <- function( xNames, data, coef, quadHalf = TRUE ) {
 
    checkNames( c( xNames ), names( data ) )
 
    nExog <- length( xNames )
    nCoef <- 1 + nExog + nExog * ( nExog + 1 ) / 2
 
-   if( nCoef != length( allCoef ) ) {
+   if( nCoef != length( coef ) ) {
       stop( "a quadratic function with ", nExog, " exogenous variables",
          " must have exactly ", nCoef, " coefficients" )
    }
 
-   alpha0 <- allCoef[ 1 ]
-   alpha  <- allCoef[ 2:( nExog + 1 ) ]
-   beta   <- vecli2m( allCoef[ ( nExog + 2 ):nCoef ] )
+   alpha0 <- coef[ 1 ]
+   alpha  <- coef[ 2:( nExog + 1 ) ]
+   beta   <- vecli2m( coef[ ( nExog + 2 ):nCoef ] )
 
    result <- rep( alpha0, nrow( data ) )
    for( i in 1:nExog ) {
