@@ -1,17 +1,17 @@
-translogCalc <- function( xNames, data, allCoef, quadHalf = TRUE,
-   logValues = FALSE ) {
+translogCalc <- function( xNames, data, coef, quadHalf = TRUE,
+   dataLogged = FALSE ) {
 
    checkNames( c( xNames ), names( data ) )
 
    nExog <- length( xNames )
    nCoef <- 1 + nExog + nExog * ( nExog + 1 ) / 2
 
-   if( nCoef != length( allCoef ) ) {
+   if( nCoef != length( coef ) ) {
       stop( "a translog function with ", nExog, " exogenous variables",
          " must have exactly ", nCoef, " coefficients" )
    }
 
-   if( logValues ) {
+   if( dataLogged ) {
       logData <- data
    } else {
       logData <- data.frame( no = c( 1:nrow( data ) ) )
@@ -20,9 +20,9 @@ translogCalc <- function( xNames, data, allCoef, quadHalf = TRUE,
       }
    }
 
-   result <- quadFuncCalc( xNames, logData, allCoef, quadHalf = quadHalf )
+   result <- quadFuncCalc( xNames, logData, coef, quadHalf = quadHalf )
 
-   if( !logValues ) {
+   if( !dataLogged ) {
       result <- exp( result )
    }
 
